summaryrefslogtreecommitdiffstats
path: root/kicker/menuext/konsole/konsolebookmarkmenu.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/menuext/konsole/konsolebookmarkmenu.cpp')
-rw-r--r--kicker/menuext/konsole/konsolebookmarkmenu.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/kicker/menuext/konsole/konsolebookmarkmenu.cpp b/kicker/menuext/konsole/konsolebookmarkmenu.cpp
index b10d26c40..1a31fe55c 100644
--- a/kicker/menuext/konsole/konsolebookmarkmenu.cpp
+++ b/kicker/menuext/konsole/konsolebookmarkmenu.cpp
@@ -1,7 +1,7 @@
#include <stdio.h>
#include <stdlib.h>
-#include <qtextstream.h>
+#include <tqtextstream.h>
#include <kbookmarkimporter.h>
#include <kmimetype.h>
@@ -14,7 +14,7 @@
#include "konsolebookmarkmenu.h"
#include "konsolebookmarkhandler.h"
-#include <qfile.h>
+#include <tqfile.h>
#include <kaction.h>
#include <klocale.h>
@@ -23,7 +23,7 @@
KonsoleBookmarkMenu::KonsoleBookmarkMenu( KBookmarkManager* mgr,
KonsoleBookmarkHandler * _owner, KPopupMenu * _parentMenu,
KActionCollection *collec, bool _isRoot, bool _add,
- const QString & parentAddress )
+ const TQString & parentAddress )
: KBookmarkMenu( mgr, _owner, _parentMenu, collec, _isRoot, _add,
parentAddress),
m_kOwner(_owner)
@@ -31,14 +31,14 @@ KonsoleBookmarkMenu::KonsoleBookmarkMenu( KBookmarkManager* mgr,
/*
* First, we disconnect KBookmarkMenu::slotAboutToShow()
* Then, we connect KonsoleBookmarkMenu::slotAboutToShow().
* They are named differently because the SLOT() macro thinks we want
* KonsoleBookmarkMenu::KBookmarkMenu::slotAboutToShow()
* Could this be solved if slotAboutToShow() is virtual in KBookmarMenu?
*/
- disconnect( _parentMenu, SIGNAL( aboutToShow() ), this,
- SLOT( slotAboutToShow() ) );
- connect( _parentMenu, SIGNAL( aboutToShow() ),
- SLOT( slotAboutToShow2() ) );
+ disconnect( _parentMenu, TQT_SIGNAL( aboutToShow() ), this,
+ TQT_SLOT( slotAboutToShow() ) );
+ connect( _parentMenu, TQT_SIGNAL( aboutToShow() ),
+ TQT_SLOT( slotAboutToShow2() ) );
}
/*
@@ -64,7 +64,7 @@ void KonsoleBookmarkMenu::refill()
{
//kdDebug(1203) << "KBookmarkMenu::refill()" << endl;
m_lstSubMenus.clear();
- QPtrListIterator<KAction> it( m_actions );
+ TQPtrListIterator<KAction> it( m_actions );
for (; it.current(); ++it )
it.current()->unplug( m_parentMenu );
m_parentMenu->clear();
@@ -86,7 +86,7 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
addNewFolder();
if ( m_pManager->showNSBookmarks()
- && QFile::exists( KNSBookmarkImporter::netscapeBookmarksFile() ) )
+ && TQFile::exists( KNSBookmarkImporter::netscapeBookmarksFile() ) )
{
m_parentMenu->insertSeparator();
@@ -98,10 +98,10 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
KonsoleBookmarkMenu *subMenu = new KonsoleBookmarkMenu( m_pManager,
m_kOwner, actionMenu->popupMenu(),
m_actionCollection, false,
- m_bAddBookmark, QString::null );
+ m_bAddBookmark, TQString::null );
m_lstSubMenus.append(subMenu);
- connect( actionMenu->popupMenu(), SIGNAL(aboutToShow()), subMenu,
- SLOT(slotNSLoad()));
+ connect( actionMenu->popupMenu(), TQT_SIGNAL(aboutToShow()), subMenu,
+ TQT_SLOT(slotNSLoad()));
}
}
@@ -111,7 +111,7 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
for ( KBookmark bm = parentBookmark.first(); !bm.isNull();
bm = parentBookmark.next(bm) )
{
- QString text = bm.text();
+ TQString text = bm.text();
text.replace( '&', "&&" );
if ( !separatorInserted && m_bIsRoot) { // inserted before the first konq bookmark, to avoid the separator if no konq bookmark
m_parentMenu->insertSeparator();
@@ -128,7 +128,7 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
// kdDebug(1203) << "Creating URL bookmark menu item for " << bm.text() << endl;
// create a normal URL item, with ID as a name
KAction * action = new KAction( text, bm.icon(), 0,
- this, SLOT( slotBookmarkSelected() ),
+ this, TQT_SLOT( slotBookmarkSelected() ),
m_actionCollection, bm.url().url().utf8() );
action->setStatusText( bm.url().prettyURL() );
@@ -163,21 +163,21 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
void KonsoleBookmarkMenu::slotBookmarkSelected()
{
KAction * a;
- QString b;
+ TQString b;
if ( !m_pOwner ) return; // this view doesn't handle bookmarks...
a = (KAction*)sender();
b = a->text();
- m_kOwner->openBookmarkURL( QString::fromUtf8(sender()->name()), /* URL */
+ m_kOwner->openBookmarkURL( TQString::fromUtf8(sender()->name()), /* URL */
( (KAction *)sender() )->text() /* Title */ );
}
void KonsoleBookmarkMenu::slotNSBookmarkSelected()
{
KAction *a;
- QString b;
+ TQString b;
- QString link(sender()->name()+8);
+ TQString link(sender()->name()+8);
a = (KAction*)sender();
b = a->text();
m_kOwner->openBookmarkURL( link, /*URL */
@@ -31,14 +31,14 @@ KonsoleBookmarkMenu::KonsoleBookmarkMenu( KBookmarkManager* mgr,
* First, we disconnect KBookmarkMenu::slotAboutToShow()
* Then, we connect KonsoleBookmarkMenu::slotAboutToShow().
- * They are named differently because the SLOT() macro thinks we want
+ * They are named differently because the TQT_SLOT() macro thinks we want
* KonsoleBookmarkMenu::KBookmarkMenu::slotAboutToShow()
* Could this be solved if slotAboutToShow() is virtual in KBookmarMenu?